@@ -29,7 +29,7 @@ set -- `ls -s ff-2836.ps` 0 no-such-file
 $verb && echo $@
 
 # did we make a plot?
-[ $1 -gt 80 ] && rm -f ./cf2836
+[ $1 -ge 76 ] && rm -f ./cf2836
 
 #
 # eof
